@@ -82,7 +82,11 @@ def get_boolean(value):
 
 def _get_os_environ():
     ret = defaults.get_defaults()
-    environkeys = [k for k in os.environ.keys() if k.startswith('OS_')]
+    environkeys = [k for k in os.environ.keys()
+                   if k.startswith('OS_')
+                   and not k.startswith('OS_TEST')  # infra CI var
+                   and not k.startswith('OS_STD')   # infra CI var
+                   ]
     if not environkeys:
         return None
     for k in environkeys:
@@ -314,6 +318,12 @@ class OpenStackConfig(object):
                     target = cloud[key]
                     del cloud[key]
             cloud[target_key] = target
+        # Because we force alignment to v3 nouns, we want to force
+        # use of the auth plugin that can do auto-selection and dealing
+        # with that based on auth parameters. v2password is basically
+        # completely broken
+        if cloud['auth_type'] == 'v2password':
+            cloud['auth_type'] = 'password'
         return cloud
 
     def _fix_backwards_interface(self, cloud):
@@ -373,8 +383,12 @@ class OpenStackConfig(object):
 
     def _validate_auth(self, config):
         # May throw a keystoneclient.exceptions.NoMatchingPlugin
-        plugin_options = ksc_auth.get_plugin_class(
-            config['auth_type']).get_options()
+        if config['auth_type'] == 'token_endpoint':
+            auth_plugin = ksc_auth.token_endpoint.Token
+        else:
+            auth_plugin = ksc_auth.get_plugin_class(config['auth_type'])
+
+        plugin_options = auth_plugin.get_options()
 
         for p_opt in plugin_options:
             # if it's in config.auth, win, kill it from config dict
